/***************************************************************************
 *   Copyright (C) 2009 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef KT_TREEFILTERMODEL_H
#define KT_TREEFILTERMODEL_H

#include <QSortFilterProxyModel>
#include <ktcore_export.h>

namespace kt
{
/**
    SortFilterProxyModel for trees, which doesn't
*/
class KTCORE_EXPORT TreeFilterModel : public QSortFilterProxyModel
{
public:
    TreeFilterModel(QObject* parent = nullptr);
    ~TreeFilterModel() override;

protected:
    bool filterAcceptsRow(int source_row, const QModelIndex& source_parent) const override;
};

}

#endif // KT_TREEFILTERMODEL_H
